unit UnidadProcedimientos;

interface
  uses inifiles, sysutils, ShlObj, ActiveX, Windows, ShellCtrls,
      controls, classes, registry, db, dialogs, forms;

  function leBoolINI (clave, cadena : string; defecto : boolean) : boolean;
  function leCadINI (clave, cadena : string; defecto : String) : String;
  function leNumINI (clave, cadena : string; defecto : Integer) : Integer;
  procedure esCadINI (clave, cadena : string; valor : String);
  procedure esBoolINI (clave, cadena : string; valor : Boolean);
  procedure esNumINI (clave, cadena : string; valor : Integer);
  function SeleccionarCarpeta (titulo : string) : string;
  function encriptar(aStr: String; aKey: Integer): String;
  function desencriptar(aStr: String; aKey: Integer): String;
  function obtenerCadenaRegistro (claveInicial : Cardinal; clave : string; valor : string) : string;
  procedure obtenerDatosODBC (odbc : string; sistema : boolean;
      var bd : string; var tipo : string; var descripcion : string;
      var controlador : string; var servidor : string;
      var listener : string; var usuario : string);

implementation

function SeleccionarCarpeta (titulo : string) : string;
var
  Inf: TBrowseInfo;
  Identificador: PItemIDList;
  Gestor : IMalloc;
  Carpeta : Array[0..MAX_PATH] Of Char;
 // handle : THandle;
begin
  With Inf Do
  Begin
    //hwndOwner := Handle;
    pidlRoot := Nil;
    pszDisplayName := Carpeta;
    lpszTitle := pchar(titulo);
    ulFlags := BIF_BROWSEINCLUDEFILES;
    lpfn := Nil;
  End;
  Identificador := SHBrowseForFolder(Inf);
  If Identificador <> Nil Then
  Begin
    SHGetPathFromIDList(Identificador, Carpeta);
    SHGetMalloc(Gestor);
    Gestor.Free(Identificador);
    SeleccionarCarpeta := Carpeta
  end;
end;


//lee un valor booleano de un fichero INI
function leBoolINI (clave, cadena : string; defecto : boolean) : boolean;
begin
  with tinifile.create (changefileext(paramstr(0),'.INI')) do
  try
    result := readbool (clave, cadena, defecto);
  finally
    free;
  end;
end;

//lee un valor numrico de un fichero INI
function leNumINI (clave, cadena : string; defecto : Integer) : Integer;
begin
  with tinifile.create (changefileext(paramstr(0),'.INI')) do
  try
    result := ReadInteger (clave, cadena, defecto);
  finally
    free;
  end;
end;

//lee un valor string de un fichero INI
function leCadINI (clave, cadena : string; defecto : String) : String;
begin
  with tinifile.create (changefileext(paramstr(0),'.INI')) do
  try
    result := ReadString (clave, cadena, defecto);
  finally
    free;
  end;
end;

//escribe un valor string en un fichero INI
procedure esCadINI (clave, cadena : string; valor : String);
begin
  with tinifile.create (changefileext(paramstr(0),'.INI')) do
  try
    WriteString (clave, cadena, valor);
  finally
    free;
  end;
end;

//escribe un valor boolean en un fichero INI
procedure esBoolINI (clave, cadena : string; valor : Boolean);
begin
  with tinifile.create (changefileext(paramstr(0),'.INI')) do
  try
    WriteBool (clave, cadena, valor);
  finally
    free;
  end;
end;

//escribe un valor numrico en un fichero INI
procedure esNumINI (clave, cadena : string; valor : Integer);
begin
  with tinifile.create (changefileext(paramstr(0),'.INI')) do
  try
    WriteInteger (clave, cadena, valor);
  finally
    free;
  end;
end;


//encriptar datos
function encriptar(aStr: String; aKey: Integer): String;
begin
   Result:='';
   RandSeed:=aKey;
   for aKey:=1 to Length(aStr) do
       Result:=Result+Chr(Byte(aStr[aKey]) xor random(256));
end;

//desencriptar datos
function desencriptar(aStr: String; aKey: Integer): String;
begin
   Result:='';
   RandSeed:=aKey;
   for aKey:=1 to Length(aStr) do
       Result:=Result+Chr(Byte(aStr[aKey]) xor random(256));
end;



function obtenerCadenaRegistro (claveInicial : Cardinal; clave : string; valor : string) : string;
var
  reg: TRegistry;
begin
  Result := '';
  Reg := TRegistry.Create;
  Reg.RootKey := claveInicial;
  reg.OpenKey(clave, False);
  try
    Result := reg.ReadString(valor);
  finally
    reg.CloseKey;
  end;
end;

procedure obtenerDatosODBC (odbc : string; sistema : boolean;
    var bd : string; var tipo : string; var descripcion : string;
    var controlador : string; var servidor : string;
    var listener : string; var usuario : string);
var
  claveInicial : Cardinal;
begin
  bd := '';
  tipo := '';
  descripcion := '';
  controlador := '';
  servidor := '';
  listener := '';
  usuario := '';
  if sistema then
    claveInicial := HKEY_LOCAL_MACHINE
  else
    claveInicial := HKEY_CURRENT_USER;
  tipo := obtenerCadenaRegistro(claveInicial,'SOFTWARE\ODBC\ODBC.INI\ODBC Data Sources',odbc);

  //Oracle
  if pos ('ORACLE', AnsiUpperCase (tipo)) > 0 then
  begin
    descripcion := obtenerCadenaRegistro(claveInicial, 'SOFTWARE\ODBC\ODBC.INI\' + odbc, 'Description');
    controlador := obtenerCadenaRegistro(claveInicial, 'SOFTWARE\ODBC\ODBC.INI\' + odbc, 'Driver');
    listener := obtenerCadenaRegistro(claveInicial, 'SOFTWARE\ODBC\ODBC.INI\' + odbc, 'ServerName');
    usuario := obtenerCadenaRegistro(claveInicial, 'SOFTWARE\ODBC\ODBC.INI\' + odbc, 'UserID');
  end;
  //MySQL
  if pos ('MYSQL', AnsiUpperCase (tipo)) > 0 then
  begin
    descripcion := obtenerCadenaRegistro(claveInicial, 'SOFTWARE\ODBC\ODBC.INI\' + odbc, 'DESCRIPTION');
    bd := obtenerCadenaRegistro(claveInicial, 'SOFTWARE\ODBC\ODBC.INI\' + odbc, 'DATABASE');
    controlador := obtenerCadenaRegistro(claveInicial, 'SOFTWARE\ODBC\ODBC.INI\' + odbc, 'Driver');
    servidor := obtenerCadenaRegistro(claveInicial, 'SOFTWARE\ODBC\ODBC.INI\' + odbc, 'SERVER');
    usuario := obtenerCadenaRegistro(claveInicial, 'SOFTWARE\ODBC\ODBC.INI\' + odbc, 'UID');
  end;
  //MS Access
  if pos ('ACCESS', AnsiUpperCase (tipo)) > 0 then
  begin
    descripcion := obtenerCadenaRegistro(claveInicial, 'SOFTWARE\ODBC\ODBC.INI\' + odbc, 'Description');
    bd := obtenerCadenaRegistro(claveInicial, 'SOFTWARE\ODBC\ODBC.INI\' + odbc, 'DBQ');
    controlador := obtenerCadenaRegistro(claveInicial, 'SOFTWARE\ODBC\ODBC.INI\' + odbc, 'Driver');
    usuario := obtenerCadenaRegistro(claveInicial, 'SOFTWARE\ODBC\ODBC.INI\' + odbc, 'UID');
  end;
  //DBASE
  if pos ('DBASE', AnsiUpperCase (tipo)) > 0 then
  begin
    descripcion := obtenerCadenaRegistro(claveInicial, 'SOFTWARE\ODBC\ODBC.INI\' + odbc, 'Description');
    controlador := obtenerCadenaRegistro(claveInicial, 'SOFTWARE\ODBC\ODBC.INI\' + odbc, 'Driver');
  end;
  //SQL SERVER
  if pos ('SQL SERVER', AnsiUpperCase (tipo)) > 0 then
  begin
    descripcion := obtenerCadenaRegistro(claveInicial, 'SOFTWARE\ODBC\ODBC.INI\' + odbc, 'Description');
    controlador := obtenerCadenaRegistro(claveInicial, 'SOFTWARE\ODBC\ODBC.INI\' + odbc, 'Driver');
    servidor := obtenerCadenaRegistro(claveInicial, 'SOFTWARE\ODBC\ODBC.INI\' + odbc, 'Server');
    usuario := obtenerCadenaRegistro(claveInicial, 'SOFTWARE\ODBC\ODBC.INI\' + odbc, 'LastUser');
  end;
  //Paradox
  if pos ('PARADOX', AnsiUpperCase (tipo)) > 0 then
  begin
    descripcion := obtenerCadenaRegistro(claveInicial, 'SOFTWARE\ODBC\ODBC.INI\' + odbc, 'Description');
    controlador := obtenerCadenaRegistro(claveInicial, 'SOFTWARE\ODBC\ODBC.INI\' + odbc, 'Driver');
    bd := obtenerCadenaRegistro(claveInicial, 'SOFTWARE\ODBC\ODBC.INI\' + odbc, 'DefaultDir');
    servidor := obtenerCadenaRegistro(claveInicial, 'SOFTWARE\ODBC\ODBC.INI\' + odbc + '\Engines\Paradox', 'ParadoxNetPath');
    usuario := obtenerCadenaRegistro(claveInicial, 'SOFTWARE\ODBC\ODBC.INI\' + odbc, 'LastUser');
  end;
  //Excel
  if pos ('EXCEL', AnsiUpperCase (tipo)) > 0 then
  begin
    descripcion := obtenerCadenaRegistro(claveInicial, 'SOFTWARE\ODBC\ODBC.INI\' + odbc, 'Description');
    controlador := obtenerCadenaRegistro(claveInicial, 'SOFTWARE\ODBC\ODBC.INI\' + odbc, 'Driver');
    bd := obtenerCadenaRegistro(claveInicial, 'SOFTWARE\ODBC\ODBC.INI\' + odbc, 'DBQ');
    servidor := obtenerCadenaRegistro(claveInicial, 'SOFTWARE\ODBC\ODBC.INI\' + odbc, 'DefaultDir');
  end;
  //TEXT, CSV
  if pos ('TEXT', AnsiUpperCase (tipo)) > 0 then
  begin
    descripcion := obtenerCadenaRegistro(claveInicial, 'SOFTWARE\ODBC\ODBC.INI\' + odbc, 'Description');
    controlador := obtenerCadenaRegistro(claveInicial, 'SOFTWARE\ODBC\ODBC.INI\' + odbc, 'Driver');
    bd := obtenerCadenaRegistro(claveInicial, 'SOFTWARE\ODBC\ODBC.INI\' + odbc, 'DefaultDir');
  end;
end;





end.
